boltun v1.0.2 Boltun.Supervisor
Summary
Functions
Starts the Boltun supervision tree. The options are:
connection: the connection parametersname: the base name to register the process.callbacks: the initial callbacks (optional)
Functions
Starts the Boltun supervision tree. The options are:
connection: the connection parametersname: the base name to register the process.callbacks: the initial callbacks (optional)
The supervisor will register each started process by using the provided name and concatenating a dot and the following suffixes:
CallbacksAgentthe agent where the callbacks are storedConnectionthe connection to the databaseListenerthe actual listener. You can use this to manage active callbacks